define(
//begin v1.x content
({
	singleSort: "단일 정렬",
	nestedSort: "중첩된 정렬",
	ascending: "오름차순",
	descending: "내림차순",
	sortingState: "${0} - ${1}",
	unsorted: "이 컬럼은 정렬하지 마십시오",
	indirectSelectionRadio: "행 ${0}, 단일 선택, 라디오 상자",
	indirectSelectionCheckBox: "행 ${0}, 다중 선택, 선택란",
	selectAll: "모두 선택"
})
//end v1.x content
);

